# FFI layer

The core part of the Glean SDK provides an FFI layer for its API.
This FFI layer can be consumed by platform-specific bindings, such as the [Kotlin bindings for Android](../android/index.md).
